"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpClientAdapter = void 0;
const axios_1 = __importDefault(require("axios"));
const context_1 = require("@nodeboot/context");
const client_1 = require("../client");
/**
 * The adapter responsible for integrating HTTP clients into the NodeBoot application lifecycle.
 *
 * This adapter:
 * - Checks if the HTTP client feature is enabled in the application.
 * - Creates and registers an Axios-based HTTP client instance.
 * - Enables HTTP logging if configured.
 * - Provides the HTTP client instance to the Dependency Injection (DI) container for injection into services.
 *
 * ## How It Works
 * 1. When an HTTP client class is decorated with `@HttpClient()`, this adapter is instantiated.
 * 2. It registers the HTTP client instance in the DI container so it can be injected into services.
 * 3. If `httpLogging` is enabled, it sets up logging for outgoing requests and incoming responses.
 *
 * ## Usage
 * Users should apply `@EnableHttpClients()` to their application and use `@HttpClient()` to register clients.
 *
 * @example
 * ```typescript
 * import { EnableHttpClients } from "@nodeboot/starter-http";
 * import { EnableDI } from "@nodeboot/di";
 * import { EnableComponentScan } from "@nodeboot/scan";
 * import { NodeBootApplication, NodeBoot, NodeBootApp, NodeBootAppView } from "@nodeboot/core";
 * import { ExpressServer } from "@nodeboot/express-server";
 * import { Container } from "typedi";
 *
 * @EnableDI(Container)
 * @EnableHttpClients()
 * @EnableComponentScan()
 * @NodeBootApplication()
 * export class SampleBackendApp implements NodeBootApp {
 *     start(): Promise<NodeBootAppView> {
 *         return NodeBoot.run(ExpressServer);
 *     }
 * }
 * ```
 *
 * @implements {ApplicationFeatureAdapter}
 */
let HttpClientAdapter = class HttpClientAdapter {
    targetClass;
    clientConfig;
    /**
     * Creates an instance of `HttpClientAdapter`.
     *
     * @param {new (...args: any[]) => any} targetClass - The class marked as an HTTP client.
     * @param {HttpClientConfig | string} clientConfig - Configuration settings for the HTTP client.
     */
    constructor(targetClass, clientConfig) {
        this.targetClass = targetClass;
        this.clientConfig = clientConfig;
    }
    /**
     * Binds the HTTP client to the NodeBoot application lifecycle.
     *
     * - Checks if HTTP clients are enabled (`@EnableHttpClients()` must be applied).
     * - Registers the HTTP client instance in the DI container.
     * - Configures HTTP request/response logging if enabled.
     *
     * @param {ApplicationFeatureContext} context - The application context providing a logger and DI container.
     */
    bind({ logger, iocContainer, config }) {
        // Check if HTTP feature is enabled
        if (context_1.ApplicationContext.get().applicationFeatures[client_1.HTTP_CLIENT_FEATURE]) {
            this.clientConfig = this.getHttpConfig(config);
            logger.info(`🌐 Registering HTTP client "${this.targetClass.name}" for target API ${this.clientConfig.baseURL}`);
            // Create and register the HTTP client
            const httpClient = axios_1.default.create(this.clientConfig);
            if (this.clientConfig.httpLogging) {
                logger.info(`HTTP logging is enabled for client ${this.targetClass.name}`);
                this.setupHttpLogging(httpClient, logger);
            }
            // Provide the client instance to the DI container
            iocContainer.set(this.targetClass, httpClient);
        }
        else {
            logger.warn(`🌐 HTTP client is disabled. Please enable HTTP client feature by decorating your application class with @EnableHttpClients()`);
        }
    }
    /**
     * Sets up HTTP request and response logging if `httpLogging` is enabled.
     *
     * Logs outgoing requests and incoming responses, and captures errors.
     *
     * @param {HttpClientStub} instance - The Axios HTTP client instance.
     * @param {LoggerService} logger - The application's logging service.
     * @private
     */
    setupHttpLogging(instance, logger) {
        instance.interceptors.request.use(request => {
            logger.debug(`<== Outgoing Request: ${request.baseURL}/${request.method?.toUpperCase()} ${request.url}`);
            return request;
        }, error => {
            console.error("Axios Request Error:", error);
            return Promise.reject(error);
        });
        instance.interceptors.response.use(response => {
            logger.debug(`==> Incoming Response: ${response.status} ${this.clientConfig.baseURL}/${response.config.url}`);
            return response;
        }, error => {
            if (error.response) {
                console.error("Axios Response Error:", {
                    status: error.response.status,
                    url: error.config.url,
                    data: error.response.data,
                });
            }
            else {
                console.error("Axios Network/Error:", error.message);
            }
            return Promise.reject(error);
        });
    }
    getHttpConfig(config) {
        if (typeof this.clientConfig === "string") {
            // resolve httpConfigs options from configurations
            const httpConfigs = this.resolveHttpConfig(config, this.clientConfig);
            if (!httpConfigs)
                throw new Error(`No http configuration object found by using ${this.clientConfig} placeholder`);
            return httpConfigs;
        }
        else {
            // use HttpClientConfig provided via decorator
            return this.clientConfig;
        }
    }
    resolveHttpConfig(config, configPathPlaceholder) {
        const configPath = (0, context_1.extractPlaceholderKey)(configPathPlaceholder);
        if (configPath) {
            return config.get(configPath);
        }
        return undefined;
    }
};
exports.HttpClientAdapter = HttpClientAdapter;
exports.HttpClientAdapter = HttpClientAdapter = __decorate([
    (0, context_1.Lifecycle)("application.started"),
    __metadata("design:paramtypes", [Function, Object])
], HttpClientAdapter);
//# sourceMappingURL=HttpClientAdapter.js.map