"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EnableHttpClients = void 0;
const context_1 = require("@nodeboot/context");
const client_1 = require("../client");
/**
 * A class decorator to enable HTTP client support in a NodeBoot application.
 *
 * This decorator activates HTTP client features within the application
 * by setting the corresponding feature flag in the application context.
 *
 * ## Usage
 * Apply this decorator to a class in a NodeBoot application to enable
 * HTTP client functionality.
 *
 * @example
 * ```typescript
 * import { Container } from "typedi";
 * import { NodeBoot, NodeBootApp, NodeBootApplication, NodeBootAppView } from "@nodeboot/core";
 * import { ExpressServer } from "@nodeboot/express-server";
 * import { EnableDI } from "@nodeboot/di";
 * import { EnableComponentScan } from "@nodeboot/scan";
 * import { EnableHttpClients } from "@nodeboot/starter-http";
 *
 * @EnableDI(Container)
 * @EnableHttpClients()
 * @EnableComponentScan()
 * @NodeBootApplication()
 * export class SampleBackendApp implements NodeBootApp {
 *     start(): Promise<NodeBootAppView> {
 *         return NodeBoot.run(ExpressServer);
 *     }
 * }
 * ```
 *
 * @returns {ClassDecorator} A decorator function that enables HTTP client support.
 */
const EnableHttpClients = () => {
    return () => {
        context_1.ApplicationContext.get().applicationFeatures[client_1.HTTP_CLIENT_FEATURE] = true;
    };
};
exports.EnableHttpClients = EnableHttpClients;
//# sourceMappingURL=EnableHttpClients.js.map